@@ -1,8 +1,8 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Authors: Jeffrey Stedfast <fejj@helixcode.com>
+ *  Authors: Jeffrey Stedfast <fejj@ximian.com>
  *
- *  Copyright 2000 Helix Code, Inc. (www.helixcode.com)
+ *  Copyright 2000-2004 Ximian, Inc. (www.ximian.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -129,12 +129,15 @@ g_mime_content_type_new_from_string (const char *string)
 	/* get the subtype */
 	if (*inptr == '/') {
 		inptr++;
+		
+		while (is_lwsp (*inptr))
+			inptr++;
+		
 		subtype = (char *) inptr;
 		while (*inptr && is_ttoken (*inptr))
 			inptr++;
 		
 		subtype = g_strndup (subtype, (unsigned) (inptr - subtype));
-		g_strstrip (subtype);
 	} else {
 		subtype = NULL;
 	}
@@ -143,6 +146,9 @@ g_mime_content_type_new_from_string (const char *string)
 	g_free (type);
 	g_free (subtype);
 	
+	while (is_lwsp (*inptr))
+		inptr++;
+	
 	if (*inptr++ == ';' && *inptr) {
 		GMimeParam *p;
 		
