@@ -2,7 +2,7 @@
 /*
  *  Authors: Jeffrey Stedfast <fejj@ximian.com>
  *
- *  Copyright 2002 Ximian, Inc. (www.ximian.com)
+ *  Copyright 2002-2004 Ximian, Inc. (www.ximian.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,26 +24,46 @@
 #ifndef __GMIME_ERROR_H__
 #define __GMIME_ERROR_H__
 
+#include <glib.h>
+
 #ifdef __cplusplus
 extern "C" {
 #pragma }
 #endif /* __cplusplus */
 
-#include <glib.h>
+extern GQuark gmime_error_quark;
+#define GMIME_ERROR_QUARK gmime_error_quark
 
-typedef enum {
+/**
+ * GMIME_ERROR:
+ *
+ * The GMime error domain GQuark value.
+ **/
+#define GMIME_ERROR GMIME_ERROR_QUARK
+
+/**
+ * GMIME_ERROR_IS_SYSTEM:
+ * @error: integer error value
+ *
+ * Decides if an error is a system error (aka errno value) vs. a GMime
+ * error.
+ *
+ * Meant to be used with GError::code
+ **/
+#define GMIME_ERROR_IS_SYSTEM(error) ((error) > 0)
+
+/* errno is a positive value, so negative values should be safe to use */
+enum {
 	GMIME_ERROR_GENERAL             =  0,
 	GMIME_ERROR_NOT_SUPPORTED       = -1,
 	GMIME_ERROR_PARSE_ERROR         = -2,
 	GMIME_ERROR_PROTOCOL_ERROR      = -3,
 	GMIME_ERROR_BAD_PASSWORD        = -4,
-	GMIME_ERROR_NO_VALID_RECIPIENTS = -5,
-} GMimeError;
-
-#define GMIME_ERROR_QUARK (g_quark_from_static_string ("gmime"))
+	GMIME_ERROR_NO_VALID_RECIPIENTS = -5
+};
 
 #ifdef __cplusplus
 }
-#endif
+#endif /* __cplusplus */
 
 #endif /* __GMIME_ERROR_H__ */
